# MBASIC Business Programs

Business applications and tools

## Available Business Programs

### Airmiles



**Year:** 1980s
**Tags:** 

**[Download airmiles.bas](airmiles.bas)**

---

### Budget



**Year:** 1980s
**Tags:** 

**[Download budget.bas](budget.bas)**

---

### Cpm-Pert



**Year:** 1980s
**Tags:** 

**[Download cpm-pert.bas](cpm-pert.bas)**

---

### Diary



**Year:** 1980s
**Tags:** 

**[Download diary.bas](diary.bas)**

---

### Finance



**Year:** 1980s
**Tags:** 

**[Download finance.bas](finance.bas)**

---

### Interest



**Year:** 1980s
**Tags:** 

**[Download interest.bas](interest.bas)**

---

### Log10K



**Year:** 1980s
**Tags:** 

**[Download log10k.bas](log10k.bas)**

---

### Mortgage



**Year:** 1980s
**Tags:** 

**[Download mortgage.bas](mortgage.bas)**

---

## How to Use

1. **Download** the .bas file you want to use
2. **Open MBASIC** in your preferred UI (Web, Tkinter, Curses, or CLI)
3. **Load the file:**
   - **Web/Tkinter UI:** Click File → Open, select the downloaded file
   - **CLI:** Type `LOAD "filename.bas"`
4. **Run:** Type `RUN` or press the Run button

## About These Business Programs

These programs are from the CP/M and early PC era (1970s-1980s), 
preserved from historical archives including OAK, Simtel, and CP/M CD-ROMs.
